@@ -65,7 +65,5 @@ def create(project_path: str, template_path: Optional[str]) -> None:
 @click.argument("template-path", nargs=-1)
 def create_command(project_path: str, template_path: Sequence[str]) -> None:
     if template_path and len(template_path) > 1:
-        echo_warning(
-            "dp create expects at most two arguments -- project-path and template-path"
-        )
+        echo_warning("dp create expects at most two arguments -- project-path and template-path")
     create(project_path, template_path[0] if template_path else None)
